@@ -186,7 +186,7 @@ class TcSoaBasics:
             attributes=[prop_name],
         )
         obj2refs_map = {bo.uid: response.modelObjects[bo.uid].prop(prop_name, db_value=True) for bo in bos}
-        return {uid: [response.modelObjects[ref] for ref in refs] for uid, refs in obj2refs_map.items()}
+        return {uid: [response.modelObjects[ref] for ref in refs if ref] for uid, refs in obj2refs_map.items()}
 
     @classmethod
     def getMultiPropObject(cls, bos: List[BusinessObject], prop_name: str):
